<?php
/**
 * @package   OSDownloads-Pro
 * @contact   www.joomlashack.com, help@joomlashack.com
 * @copyright 2005-2020 Joomlashack.com. All rights reserved
 * @license   http://www.gnu.org/licenses/gpl.html GNU/GPL
 *
 * This file is part of OSDownloads-Pro.
 *
 * OSDownloads-Pro is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 2 of the License, or
 * (at your option) any later version.
 *
 * OSDownloads-Pro is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with OSDownloads-Pro.  If not, see <http://www.gnu.org/licenses/>.
 */

use Alledia\OSDownloads\Pro\MailingList\AcyMailing;

defined('_JEXEC') or die();

JFormHelper::loadFieldType('List');

require_once __DIR__ . '/MailinglistFieldTraits.php';

class OsdownloadsFormFieldAcymailinglist extends JFormFieldList
{
    use MailinglistFieldTraits;

    public function setup(SimpleXMLElement $element, $value, $group = null)
    {
        $success = $this->isMailinglistEnabled('acymailing')
            && parent::setup($element, $value, $group);

        if ($success && !defined('OSDOWNLOADS_LOADED')) {
            $includePath = JPATH_ADMINISTRATOR . '/components/com_osdownloads/include.php';
            if ($success = is_file($includePath)) {
                require_once $includePath;
            }
        }

        return $success;
    }

    /**
     * @return object[]
     * @throws Exception
     */
    protected function getOptions()
    {
        $options = array();

        try {
            $lists = AcyMailing::getLists();

            foreach ($lists as $list) {
                $options[] = JHtml::_('select.option', $list->id, $list->name);
            }

        } catch (Exception $error) {
            JFactory::getApplication()->enqueueMessage($error->getMessage(), 'error');
        }

        return array_merge(parent::getOptions(), $options);
    }
}
