<?php
/**
 * @package   OSDownloads-Pro
 * @contact   www.joomlashack.com, help@joomlashack.com
 * @copyright 2005-2020 Joomlashack.com. All rights reserved
 * @license   http://www.gnu.org/licenses/gpl.html GNU/GPL
 *
 * This file is part of OSDownloads-Pro.
 *
 * OSDownloads-Pro is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 2 of the License, or
 * (at your option) any later version.
 *
 * OSDownloads-Pro is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with OSDownloads-Pro.  If not, see <http://www.gnu.org/licenses/>.
 */

use Joomla\Registry\Registry;

defined('_JEXEC') or die();

require_once __DIR__ . '/AbstractMailChimp.php';

class OsdownloadsFormFieldMailChimpGroup extends AbstractMailChimp
{
    /**
     * @var string
     */
    protected $type = 'osdownloads.mailchimpgroup';

    /**
     * @var object[]
     */
    protected $mailchimpOptions = null;

    /**
     * @return object[]
     * @throws Exception
     */
    protected function getMailchimpOptions()
    {
        if ($this->mailchimpOptions === null) {
            $this->mailchimpOptions = array();

            $listId = $this->getListId();
            if (!$listId) {
                JHtml::_('behavior.tooltip');
                $this->setError(
                    sprintf(
                        '<span>%s <i class="icon-info hasTip" title="%s"></i></span>',
                        JText::_('COM_OSDOWNLOADS_ML_MAILCHIMP_GROUPS_SELECT_LIST'),
                        JText::_('COM_OSDOWNLOADS_ML_MAILCHIMP_GROUPS_SELECT_LIST_TOOLTIP')
                    )
                );

            } else {
                try {
                    $groups = $this->getMailchimpGroups($listId);
                    if (!$groups) {
                        $this->setError(JText::_('COM_OSDOWNLOADS_ML_MAILCHIMP_NO_GROUPS'));

                    } else {
                        foreach ($groups as $group) {
                            $this->mailchimpOptions[] = JHtml::_(
                                'select.option',
                                $group->id,
                                sprintf('%s/%s', $group->category, $group->interest)
                            );
                        }
                    }

                } catch (Exception $error) {
                    $this->setError($error->getMessage());
                }
            }
        }

        return $this->mailchimpOptions;
    }

    /**
     * @return string
     */
    protected function getListId()
    {
        $listFieldName  = (string)$this->element['list_id'] ?: 'list_id';
        $fieldNameAtoms = explode('.', $listFieldName);

        $fieldName  = array_shift($fieldNameAtoms);
        $fieldGroup = join('.', $fieldNameAtoms) ?: $this->group;

        $listField = $this->form->getField($fieldName, $fieldGroup);

        $listId = $listField ? $listField->value : null;

        return $listId;
    }
}
