<?php
/**
 * @package   OSDownloads-Pro
 * @contact   www.joomlashack.com, help@joomlashack.com
 * @copyright 2005-2020 Joomlashack.com. All rights reserved
 * @license   http://www.gnu.org/licenses/gpl.html GNU/GPL
 *
 * This file is part of OSDownloads-Pro.
 *
 * OSDownloads-Pro is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 2 of the License, or
 * (at your option) any later version.
 *
 * OSDownloads-Pro is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with OSDownloads-Pro.  If not, see <http://www.gnu.org/licenses/>.
 */

use Joomla\CMS\Form\FormField;

defined('_JEXEC') or die();

require_once __DIR__ . '/AbstractMailChimp.php';

class OsdownloadsFormFieldMailchimplist extends AbstractMailChimp
{
    /**
     * @var string
     */
    protected $type = 'osdownloads.mailchimplist';

    /**
     * @var object[]
     */
    protected $mailchimpOptions = null;

    /**
     * @var FormField
     */
    protected $category = null;

    /**
     * @return object[]
     */
    protected function getMailchimpOptions()
    {
        if ($this->mailchimpOptions === null) {
            $this->mailchimpOptions = array();

            try {
                $lists = $this->getMailchimpLists();
                if (!$lists) {
                    $this->setError(JText::_('COM_OSDOWNLOADS_ML_MAILCHIMP_NO_LISTS'));

                } else {
                    foreach ($lists as $list) {
                        $this->mailchimpOptions[] = JHtml::_('select.option', $list->id, $list->name);
                    }
                }

            } catch (Exception $error) {
                $this->setError($error->getMessage());
            }
        }

        return $this->mailchimpOptions;
    }

    /**
     * @return object[]
     * @throws Exception
     */
    protected function getOptions()
    {
        $options = parent::getOptions();

        if ($this->element['useglobal']) {
            $defaultOption = $this->findOption('', $options);
            $paramKey      = 'mailinglist.mailchimp.' . $this->fieldname;

            if ($defaultOption !== null) {
                $default = &$options[$defaultOption];
                $option  = $this->app->input->getCmd('option');

                if ($option == 'com_osdownloads' && $this->getCategoryField()) {
                    // Expect to be from a file editing form
                    $default->text = JText::_('COM_OSDOWNLOADS_INHERIT_FROM_CATEGORY');

                } else {
                    $inheritedId = JComponentHelper::getParams('com_osdownloads')->get($paramKey);

                    if ($inheritedId === null) {
                        $default->text = JText::_('COM_OSDOWNLOADS_SELECT_LIST');

                    } else {
                        $listOption = $this->findOption($inheritedId, $options);

                        if ($listOption !== null) {
                            $default->text = JText::sprintf('JGLOBAL_USE_GLOBAL_VALUE', $options[$listOption]->text);
                        }
                    }
                }
            }
        }

        return $options;
    }

    /**
     * @param string   $value
     * @param object[] $options
     *
     * @return int
     */
    protected function findOption($value, array $options)
    {
        foreach ($options as $index => $option) {
            if ($option->value == $value) {
                return $index;
            }
        }

        return null;
    }

    /**
     * @param string $categoryField
     *
     * @return FormField
     */
    protected function getCategoryField($categoryField = null)
    {
        if ($this->category === null) {
            $categoryField = $categoryField ?: (string)$this->element['categoryfield'] ?: 'cate_id';
            $categoryAtoms = explode('.', $categoryField);

            $fieldName = array_shift($categoryAtoms);
            $groupName = join('.', $categoryAtoms);

            if ($category = $this->form->getField($fieldName, $groupName)) {
                $this->category = $category;
            }
        }

        return $this->category;
    }
}
