<?php
/**
 * @package   OSDownloads-Pro
 * @contact   www.joomlashack.com, help@joomlashack.com
 * @copyright 2005-2020 Joomlashack.com. All rights reserved
 * @license   http://www.gnu.org/licenses/gpl.html GNU/GPL
 *
 * This file is part of OSDownloads-Pro.
 *
 * OSDownloads-Pro is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 2 of the License, or
 * (at your option) any later version.
 *
 * OSDownloads-Pro is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with OSDownloads-Pro.  If not, see <http://www.gnu.org/licenses/>.
 */

namespace Alledia\OSDownloads\Pro\Helper;

use JComponentHelper;
use JHtmlSidebar;
use JText;
use JFactory;
use JModelLegacy;
use Alledia\OSDownloads\Free\Helper\Helper as FreeHelper;

defined('_JEXEC') or die();

class Helper extends FreeHelper
{
    /**
     * @param string $vName
     *
     * @return void
     * @throws \Exception
     */
    public static function addSubmenu($vName)
    {
        parent::addSubmenu($vName);

        if (JComponentHelper::isEnabled('com_osdownloads')) {
            // Get the context defined in the URL
            $context = JFactory::getApplication()->input->getCmd('context');

            if (empty($context)) {
                \JModelLegacy::addIncludePath(JPATH_ADMINISTRATOR . '/components/com_fields/models');
                $model = JModelLegacy::getInstance('Fields', 'FieldsModel');
                if (is_object($model)) {
                    $context = $model->getState('filter.context');
                }
            }

            if (JComponentHelper::isEnabled('com_fields')) {
                JHtmlSidebar::addEntry(
                    JText::_('COM_OSDOWNLOADS_FILE_FIELDS'),
                    'index.php?option=com_fields&context=com_osdownloads.file',
                    'fields.fields' === $vName && 'com_osdownloads.file' === $context
                );

                JHtmlSidebar::addEntry(
                    JText::_('COM_OSDOWNLOADS_FILE_FIELD_GROUPS'),
                    'index.php?option=com_fields&view=groups&context=com_osdownloads.file',
                    'fields.groups' === $vName && 'com_osdownloads.file' === $context
                );

                JHtmlSidebar::addEntry(
                    JText::_('COM_OSDOWNLOADS_DOWNLOAD_FIELDS'),
                    'index.php?option=com_fields&context=com_osdownloads.download',
                    'fields.fields' === $vName && 'com_osdownloads.download' === $context
                );

                JHtmlSidebar::addEntry(
                    JText::_('COM_OSDOWNLOADS_DOWNLOAD_FIELD_GROUPS'),
                    'index.php?option=com_fields&view=groups&context=com_osdownloads.download',
                    'fields.groups' === $vName && 'com_osdownloads.download' === $context
                );

            } else {
                JHtmlSidebar::addEntry(
                    sprintf(
                        '<div class="alert alert-info">%s</div>',
                        JText::_('COM_OSDOWNLOADS_WARN_CUSTOM_FIELDS_DISABLED')
                    ),
                    ''
                );
            }
        }
    }

    /**
     * Returns valid contexts
     *
     * @return  array
     *
     * @since   3.7.0
     */
    public static function getContexts()
    {
        JFactory::getLanguage()->load('com_osdownloads', JPATH_ADMINISTRATOR);

        $contexts = array(
            'com_osdownloads.file' => JText::_('COM_OSDOWNLOADS_FILE'),
        );

        return $contexts;
    }
}
