<?php
/**
 * @package   OSDownloads-Pro
 * @contact   www.joomlashack.com, help@joomlashack.com
 * @copyright 2005-2020 Joomlashack.com. All rights reserved
 * @license   http://www.gnu.org/licenses/gpl.html GNU/GPL
 *
 * This file is part of OSDownloads-Pro.
 *
 * OSDownloads-Pro is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 2 of the License, or
 * (at your option) any later version.
 *
 * OSDownloads-Pro is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with OSDownloads-Pro.  If not, see <http://www.gnu.org/licenses/>.
 */

namespace Alledia\OSDownloads\Pro\Joomla\Controller\Admin;

use Alledia\OSDownloads\Free\Joomla\Controller\Admin\Emails as FreeEmailsController;
use Alledia\Framework\Factory;
use JFile;
use JFolder;
use JText;
use JRoute;
use Exception;

defined('_JEXEC') or die();

class Emails extends FreeEmailsController
{
    const CSV_BASE_PATH = '/media/com_osdownloads/csv/';

    public function export()
    {
        $app = Factory::getApplication();
        $db  = Factory::getDBO();

        $search    = $app->getUserStateFromRequest('osdownloads.email.request.search', 'search', "");
        $cateId    = $app->getUserStateFromRequest('osdownloads.email.request.cateId', 'cate_id');
        $order     = $app->getUserStateFromRequest("osdownloads.email.order", 'filter_order', 'email.id', 'cmd');
        $orderDir  = $app->getUserStateFromRequest("osdownloads.email.orderDir", 'filter_order_Dir', 'DESC', 'word');
        $confirmed = $app->getUserStateFromRequest("osdownloads.email.confirmed", 'filter_confirmed', '-1', 'int');

        $query = $db->getQuery(true);

        $query->select("email.*, doc.name AS doc_name, cat.id as cat_id, cat.title AS cat_title");
        $query->from("#__osdownloads_emails email");
        $query->join("LEFT", "#__osdownloads_documents doc ON (email.document_id = doc.id)");
        $query->join("LEFT", "#__categories cat ON (cat.id = doc.cate_id)");

        if ($search) {
            $query->where("email.email LIKE '%{$search}%' OR doc.name LIKE '%{$search}%'");
        }
        if ($cateId) {
            $query->where("cat.id = {$cateId}");
        }

        if ($confirmed >= 0) {
            $query->where('email.confirmed = ' . $db->quote($confirmed));
        }

        $query->order(" $order  $orderDir");

        $db->setQuery($query);

        $items = (array)$db->loadObjectList();

        $delimiter = ',';
        $quote     = '"';

        $model = $this->getModel('Emails');

        $titleRow = array(
            'id',
            'email',
            'document_id',
            'downloaded_on',
            'hash',
            'confirmed',
            'document_name',
            'category_id',
            'category_title',
            'synced',
        );

        $dataRows = array();

        // Add the custom fields names to the title column
        $fields = $model->getCustomFieldsNames();

        if (!empty($fields)) {
            foreach ($fields as $field) {
                $titleRow[] = $field->name;
            }
        }

        foreach ($items as $item) {
            $row = array(
                $item->id,
                $item->email,
                $item->document_id,
                $item->downloaded_date,
                $item->hash,
                $item->confirmed,
                $item->doc_name,
                $item->cat_id,
                $item->cat_title,
                $item->synced,
            );

            // User data
            $userData = $model->getCustomFieldsValuesByFieldName($item);

            // Check for each field name, so the fields with no value we add a blank column
            foreach ($fields as $field) {
                if (isset($userData[$field->name])) {
                    $row[] = $userData[$field->name];
                } else {
                    $row[] = '';
                }
            }

            $dataRows[] = $quote . implode($quote . $delimiter . $quote, $row) . $quote;
        }

        // Build the CSV data
        $csv = implode($delimiter, $titleRow) . "\n";
        $csv .= implode("\n", $dataRows);

        // Work on the file
        $rand     = bin2hex(openssl_random_pseudo_bytes(64));
        $url      = JRoute::_('index.php?option=com_osdownloads&view=emails&task=emails.downloadcsv&hash=' . $rand);
        $fileName = JPATH_SITE . static::CSV_BASE_PATH . $rand . '.csv';

        // Remove old files
        $files = JFolder::files(JPATH_SITE . static::CSV_BASE_PATH, '.csv', false, true);
        if (!empty($files)) {
            foreach ($files as $file) {
                JFile::delete($file);
            }
        }

        // Save the new file
        JFile::write($fileName, $csv);

        $message = JText::_("COM_OSDOWNLOADS_LIST_SUCCESSFULLY_EXPORTED")
            . " <a href=\"{$url}\" target=\"_blank\">"
            . JText::_("COM_OSDOWNLOADS_DOWNLOAD_CSV_FILE")
            . "</a> " . JText::_("COM_OSDOWNLOADS_LIST_CSV_WILL_BE_DELETED");

        $this->setRedirect("index.php?option=com_osdownloads&view=emails", $message);
    }

    public function downloadcsv()
    {
        $app = Factory::getApplication();

        $hash = $app->input->get('hash', '');
        $path = JPATH_SITE . static::CSV_BASE_PATH . '/' . $hash . '.csv';

        if (empty($hash) || !JFile::exists($path)) {
            throw new Exception("Error Processing Download Request");
        }

        header('Content-Type: text/csv; charset=utf-8');
        header('Content-Disposition: attachment; filename=osdownloads_emails.csv');

        echo file_get_contents($path);

        // Removes the file
        JFile::delete($path);

        jexit();
    }
}
