<?php
/**
 * @package   OSDownloads-Pro
 * @contact   www.joomlashack.com, help@joomlashack.com
 * @copyright 2005-2020 Joomlashack.com. All rights reserved
 * @license   http://www.gnu.org/licenses/gpl.html GNU/GPL
 *
 * This file is part of OSDownloads-Pro.
 *
 * OSDownloads-Pro is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 2 of the License, or
 * (at your option) any later version.
 *
 * OSDownloads-Pro is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with OSDownloads-Pro.  If not, see <http://www.gnu.org/licenses/>.
 */

namespace Alledia\OSDownloads\Pro\Joomla\Controller;

defined('_JEXEC') or die();

use Alledia\Framework\Factory;
use Alledia\OSDownloads\Free\Joomla\Controller\Site as FreeControllerSite;
use Alledia\OSDownloads\Free\Joomla\Component\Site as FreeComponentSite;
use Alledia\OSDownloads\Free\Helper\Helper;
use Alledia\OSDownloads\Free\Joomla\Table\Email;
use Exception;
use JRoute;
use JUri;
use JText;
use JPluginHelper;
use JEventDispatcher;

class Site extends FreeControllerSite
{
    /**
     * Task called by clicking on the download link sent by e-mail
     *
     * @return void
     * @throws Exception
     */
    public function confirmemail()
    {
        $app       = Factory::getApplication();
        $component = FreeComponentSite::getInstance();

        $data = @json_decode(base64_decode($app->input->getBase64('data', '')));

        if (!empty($data)) {
            /** @var \OSDownloadsModelItem $modelItem */
            $modelItem = $component->getModel('Item');

            /** @var \OSDownloadsModelEmail $modelEmail */
            $modelEmail = $component->getModel('Email');

            $email = $modelEmail->getEmail((int)$data->email_id);
            $item  = $modelItem->getItem((int)$data->document_id);

            if (!empty($email) && !empty($item)) {
                $email->confirmed = ($data->hash === $email->hash);
                $email->store();

                $this->notifyAdministrators($item, $email->email, $email);

                $app->redirect(JRoute::_('index.php?option=com_osdownloads&task=download&id=' . $item->id));
            }
        }

        // Invalid data
        $app->input->set('layout', 'error_invalid_data');
        $app->input->set('view', 'item');

        $this->display();
    }

    /**
     * @param object $item
     *
     * @return bool
     * @throws Exception
     */
    protected function processEmailRequirement($item)
    {
        $app                  = Factory::getApplication();
        $params               = $app->getParams('com_osdownloads');
        $useEmailConfirmation = (bool)$params->get('use_email_confirmation', 0);
        $component            = FreeComponentSite::getInstance();
        $email                = $app->input->get('require_email', null, 'raw');

        // Must verify the e-mail before download?
        if ($item->require_user_email == 1 || ($item->require_user_email == 2 && !empty($email))) {
            if (!Helper::validateEmail($email)) {
                $app->input->set('layout', 'error_invalid_email');

                return false;
            }

            /** @var \OSDownloadsModelEmail $modelEmail */
            $modelEmail = $component->getModel('Email');
            $emailRow   = $modelEmail->insert($email, $item->id);

            if ($emailRow) {
                // In the Pro version this will allow com_files to save the custom fields values.
                JPluginHelper::importPlugin('content');
                $dispatcher = JEventDispatcher::getInstance();
                $dispatcher->trigger(
                    'onContentAfterSave',
                    array('com_osdownloads.download', &$emailRow, false, $_POST)
                );

                if ($useEmailConfirmation) {
                    // Send e-mail with a link
                    $mailer = Factory::getMailer();
                    $config = Factory::getConfig();

                    $mailer->addRecipient($email);

                    $data      = array(
                        'document_id' => $item->id,
                        'email_id'    => $emailRow->id,
                        'hash'        => $emailRow->hash
                    );
                    $linkQuery = array(
                        'option' => 'com_osdownloads',
                        'task'   => 'confirmemail',
                        'data'   => base64_encode(json_encode($data))
                    );

                    $downloadLink = JRoute::_('index.php?' . http_build_query($linkQuery), true);
                    $downloadUrl  = JUri::getInstance()->toString(array('scheme', 'host', 'port')) . $downloadLink;

                    // Subject
                    $emailSubject = $params->get('email_confirmation_subject');
                    if (empty($emailSubject)) {
                        $emailSubject = $config->get('sitename') . ' - ' . JText::_('COM_OSDOWNLOADS_DOWNLOAD_LINK');
                    }

                    // Body
                    $emailBody = $params->get('email_confirmation_body');
                    if (empty($emailBody)) {
                        $emailBody = '<h1>' . $config->get('sitename') . '</h1>';
                        $emailBody .= '<h2>' . $item->name . '</h2>';
                        $emailBody .= JText::_('COM_OSDOWNLOADS_EMAIL_DOWNLOAD_LINK_MESSAGE');
                    }

                    $emailSubject = $this->replaceFileInfoTokens($item, $downloadUrl, $emailSubject);
                    $emailBody    = $this->replaceFileInfoTokens($item, $downloadUrl, $emailBody);


                    if ($this->sendEmail($email, $emailSubject, $emailBody)) {
                        $app->input->set('layout', 'thankyou_email_sent');
                    } else {
                        $app->input->set('layout', 'error_sending_email');
                    }

                } else {
                    $emailRow->store();

                    // Download directly
                    $this->notifyAdministrators($item, $email, $emailRow);

                    $app->input->set('layout', 'thankyou');
                }

            } else {
                $app->input->set('layout', 'error_invalid_email');
            }

        } else {
            $this->notifyAdministrators($item, $email);
            $app->input->set('layout', 'thankyou');
        }

        return true;
    }

    /**
     * Replace known shortcode tokens with data from object
     *
     * @param object $item
     * @param string $downloadUrl
     * @param string $text
     *
     * @return mixed
     */
    protected function replaceFileInfoTokens($item, $downloadUrl, $text)
    {
        $replacements = array(
            '{{download_url}}' => $downloadUrl,
            '{{name}}'         => empty($item->name) ? '[item Name]' : $item->name,
            '{{category}}'     => empty($item->cat_title) ? '[item Category]' : $item->cat_title
        );

        return str_replace(array_keys($replacements), $replacements, $text);
    }

    /**
     * @param array|string $recipients
     * @param string       $subject
     * @param string       $body
     * @param bool         $bcc
     *
     * @return bool
     * @throws Exception
     */
    public static function sendEmail($recipients, $subject, $body, $bcc = false)
    {
        $params = Factory::getApplication()->getParams('com_osdownloads');
        $mailer = Factory::getMailer();
        $config = Factory::getConfig();

        $mailer->setSender(
            array(
                $params->get('notification.mailfrom') ?: $config->get('mailfrom'),
                $params->get('notification.fromname') ?: $config->get('fromname')
            )
        );

        foreach ((array)$recipients as $recipient) {
            if ($bcc) {
                $mailer->addBcc($recipient);
            } else {
                $mailer->addRecipient($recipient);
            }
        }

        $mailer->isHTML(true);

        $subject = $subject ?: $config->get('sitename') . ' - ' . JText::_('COM_OSDOWNLOADS_DOWNLOAD_LINK');

        $mailer->setSubject($subject);
        $mailer->setBody($body);

        return $mailer->Send();
    }

    /**
     * Send administrator notifications according to configuration
     *
     * @param object $item
     * @param string $email
     * @param Email  $collectedEmailEntryItem
     *
     * @return void
     * @throws Exception
     */
    protected function notifyAdministrators(
        $item,
        $email = null,
        Email $collectedEmailEntryItem = null
    ) {
        $params = Factory::getApplication()->getParams('com_osdownloads');
        if ($params->get('notification.enabled')) {
            $db = Factory::getDbo();

            $recipients = array();
            if ($params->get('notification.system')) {
                // Gather system users
                $recipients = $db->setQuery(
                    $db->getQuery(true)
                        ->select('email')
                        ->from('#__users')
                        ->where(
                            array(
                                $db->quoteName('sendEmail') . '= 1',
                                $db->quoteName('block') . ' = 0'
                            )
                        )
                )
                    ->loadColumn();
            }

            if ($additional = $params->get('notification.additional')) {
                $recipients = array_unique(
                    array_merge(
                        $recipients,
                        array_filter(
                            array_map('trim', preg_split('/[\r\n,]/', $additional))
                        )
                    )
                );
            }

            if ($recipients) {
                $app  = \JFactory::getApplication();
                $user = \JFactory::getUser();

                $body = JText::sprintf(
                    'COM_OSDOWNLOADS_NOTIFICATION_BODY',
                    $item->name,
                    $item->id,
                    $email ?: $user->email ?: JText::_('COM_OSDOWNLOADS_GUEST')
                );

                if ($collectedEmailEntryItem) {
                    $component = FreeComponentSite::getInstance();

                    /** @var \OsdownloadsModelEmails $modelEmails */
                    $modelEmails        = $component->getModel('Emails');
                    $customFieldsValues = $modelEmails->getCustomFieldsValuesAsString($collectedEmailEntryItem);

                    $body .= '<br>' . $customFieldsValues;
                }

                $this->sendEmail(
                    $recipients,
                    JText::sprintf('COM_OSDOWNLOADS_NOTIFICATION_SUBJECT', $app->get('sitename')),
                    $body,
                    false
                );
            }
        }
    }
}
