<?php
/**
 * @package   OSDownloads-Pro
 * @contact   www.joomlashack.com, help@joomlashack.com
 * @copyright 2005-2020 Joomlashack.com. All rights reserved
 * @license   http://www.gnu.org/licenses/gpl.html GNU/GPL
 *
 * This file is part of OSDownloads-Pro.
 *
 * OSDownloads-Pro is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 2 of the License, or
 * (at your option) any later version.
 *
 * OSDownloads-Pro is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with OSDownloads-Pro.  If not, see <http://www.gnu.org/licenses/>.
 */

namespace Alledia\OSDownloads\Pro\Joomla\Model;

defined('_JEXEC') or die();

use Alledia\Framework\Joomla\Model\Base as BaseModel;
use Alledia\Framework\Factory;
use Alledia\OSDownloads\Free\Joomla\Component\Site as FreeComponentSite;
use Exception;
use JDatabaseQuery;
use JFactory;


class Categories extends BaseModel
{
    /**
     * Get the categories query
     *
     * @param int $catId
     *
     * @return JDatabaseQuery
     * @throws Exception
     */
    public function getItemQuery($catId = null)
    {
        $app    = JFactory::getApplication();
        $db     = $this->getDBO();
        $user   = Factory::getUser();
        $groups = $user->getAuthorisedViewLevels();

        $filterOrder    = $app->getUserStateFromRequest(
            'com_osdownloads.category.filter_order',
            'filter_order',
            'cat.lft',
            ''
        );
        $filterOrderDir = $app->getUserStateFromRequest(
            'com_osdownloads.category.filter_order_Dir',
            'filter_order_Dir',
            'asc',
            'word'
        );

        $query = $db->getQuery(true)
            ->select('cat.*')
            ->from('#__categories AS cat')
            ->where(
                array(
                    'cat.published = 1',
                    'cat.access IN (' . implode(',', $groups) . ')',
                    'cat.extension = ' . $db->quote('com_osdownloads')
                )
            )
            ->order($db->quoteName($filterOrder) . ' ' . $filterOrderDir);

        if (!empty($catId)) {
            $query->where('cat.id = ' . $db->quote((int)$catId));
        }

        return $query;
    }

    /**
     * Get the child categories query
     *
     * @param int $parentId
     *
     * @return JDatabaseQuery
     * @throws Exception
     */
    public function getChildCategoriesQuery($parentId = null)
    {
        $app    = JFactory::getApplication();
        $db     = $this->getDBO();
        $user   = Factory::getUser();
        $groups = $user->getAuthorisedViewLevels();

        // Make sure if we don't have a category, we use the root category
        if (empty($parentId)) {
            $parentId = 1;
        }

        $filterOrder    = $app->getUserStateFromRequest(
            'com_osdownloads.category.filter_order',
            'filter_order',
            'cat.lft',
            ''
        );
        $filterOrderDir = $app->getUserStateFromRequest(
            'com_osdownloads.category.filter_order_Dir',
            'filter_order_Dir',
            'asc',
            'word'
        );

        $query = $db->getQuery(true)
            ->select('cat.*')
            ->from('#__categories AS cat')
            ->where(
                array(
                    'cat.published = 1',
                    'cat.access IN (' . implode(',', $groups) . ')',
                    'cat.extension = ' . $db->quote('com_osdownloads'),
                    'cat.parent_id = ' . $db->quote((int)$parentId)
                )
            )
            ->order($db->quoteName($filterOrder) . ' ' . $filterOrderDir);

        return $query;
    }

    /**
     * Get the total of files a category have
     *
     * @param  int $catId
     *
     * @return int
     */
    public function getTotalCategoryFiles($catId)
    {
        $db     = $this->getDBO();
        $user   = Factory::getUser();
        $groups = $user->getAuthorisedViewLevels();

        $query = $db->getQuery(true)
            ->select('count(*)')
            ->from('#__osdownloads_documents')
            ->where(
                array(
                    // It must be published
                    'published = 1',
                    // The user needs to have access to it
                    'access IN (' . implode(',', $groups) . ')',
                    'cate_id = ' . $db->quote((int)$catId)
                )
            );
        $db->setQuery($query);

        $total = (int)$db->loadResult();

        return $total;
    }

    /**
     * Get the total of child categories a category has.
     *
     * @param  int $catId
     *
     * @return int
     */
    public function getTotalCategoryChildren($parentId)
    {
        $db     = $this->getDBO();
        $user   = Factory::getUser();
        $groups = $user->getAuthorisedViewLevels();

        $query = $db->getQuery(true)
            ->select('count(*)')
            ->from('#__categories AS cat')
            ->where(
                array(
                    // It must be published
                    'cat.published = 1',
                    // The user needs to have access to it
                    'cat.access IN (' . implode(',', $groups) . ')',
                    'cat.extension = ' . $db->quote('com_osdownloads'),
                    'cat.parent_id = ' . $db->quote((int)$parentId)
                )
            );
        $db->setQuery($query);

        $total = (int)$db->loadResult();

        return $total;
    }
}
