<?php
/**
 * @package   OSDownloads-Pro
 * @contact   www.joomlashack.com, help@joomlashack.com
 * @copyright 2005-2020 Joomlashack.com. All rights reserved
 * @license   http://www.gnu.org/licenses/gpl.html GNU/GPL
 *
 * This file is part of OSDownloads-Pro.
 *
 * OSDownloads-Pro is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 2 of the License, or
 * (at your option) any later version.
 *
 * OSDownloads-Pro is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with OSDownloads-Pro.  If not, see <http://www.gnu.org/licenses/>.
 */

namespace Alledia\OSDownloads\Pro\Joomla\Model;

defined('_JEXEC') or die();

use Alledia\OSDownloads\Free\Joomla\Model\Emails as FreeEmails;
use JFactory;
use JText;

class Emails extends FreeEmails
{
    /**
     * Get the values of custom fields for the givem item.
     *
     * @param  object $item
     *
     * @return array
     */
    public function getCustomFieldsValues($item)
    {
        $db = JFactory::getDBO();

        $query = $db->getQuery(true)
            ->select(
                array(
                    'val.value AS value',
                    'field.name AS name',
                    'field.title AS title',
                )
            )
            ->from('#__fields_values AS val')
            ->innerjoin('#__fields AS field ON (field.context = "com_osdownloads.download" AND val.field_id = field.id)')
            ->where('val.item_id = ' . $db->quote($item->id));

        $data = $db->setQuery($query)->loadObjectList();

        return $data;
    }

    /**
     * Get the values of custom fields for the givem item, returning as string.
     *
     * @param  object $item
     *
     * @return string
     */
    public function getCustomFieldsValuesAsString($item)
    {
        $values = $this->getCustomFieldsValues($item);

        $output = array();
        if (is_array($values)) {
            foreach ($values as $value) {
                $output[] = JText::_($value->title) . ': ' . $value->value;
            }
        }

        $output = implode('<br>', $output);

        return $output;
    }

    /**
     * Get the list of custom fields
     *
     * @return array
     */
    public function getCustomFieldsNames()
    {
        $db = JFactory::getDBO();

        $query = $db->getQuery(true)
            ->select('field.name AS name')
            ->from('#__fields AS field')
            ->where('field.context = "com_osdownloads.download"');

        $fields = $db->setQuery($query)->loadObjectList();

        return $fields;
    }

    /**
     * Get the values of custom fields for the givem item, by the field name.
     *
     * @param  object $item
     *
     * @return array
     */
    public function getCustomFieldsValuesByFieldName($item)
    {
        $data = $this->getCustomFieldsValues($item);

        $processedList = array();

        if (!empty($data)) {
            foreach ($data as $row) {
                $processedList[$row->name] = $row->value;
            }
        }

        return $processedList;
    }
}
