<?php
/**
 * @package   OSDownloads-Pro
 * @contact   www.joomlashack.com, help@joomlashack.com
 * @copyright 2005-2020 Joomlashack.com. All rights reserved
 * @license   http://www.gnu.org/licenses/gpl.html GNU/GPL
 *
 * This file is part of OSDownloads-Pro.
 *
 * OSDownloads-Pro is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 2 of the License, or
 * (at your option) any later version.
 *
 * OSDownloads-Pro is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with OSDownloads-Pro.  If not, see <http://www.gnu.org/licenses/>.
 */

namespace Alledia\OSDownloads\Pro\Joomla\Model;

defined('_JEXEC') or die();

use Alledia\Framework\Factory;
use Alledia\OSDownloads\Free\Joomla\Model\Item as FreeItem;
use Alledia\OSDownloads\Free\Joomla\Component\Site as FreeComponentSite;
use Exception;
use JDatabaseQuery;

class Item extends FreeItem
{
    /**
     * Get the document's query
     *
     * @param  int $documentId
     *
     * @return JDatabaseQuery
     * @throws Exception
     */
    public function getItemQuery($documentId = null)
    {
        $db        = $this->getDBO();
        $query     = parent::getItemQuery($documentId);
        $date      = Factory::getDate();
        $component = FreeComponentSite::getInstance();

        $today = $date->toSQL();

        $today     = $db->quote($today);
        $emptyDate = $db->quote('0000-00-00 00:00:00');

        $query->where(
            array(
                "(doc.publish_up = {$emptyDate} OR doc.publish_up <= {$today})",
                "(doc.publish_down = {$emptyDate} OR doc.publish_down >= {$today})"
            )
        );

        // Override the require_email data based on the require_email_only_guest param
        $requireEmailOnlyGuest = (bool)$component->params->get('require_email_only_guest', 1);
        $requireEmailOverride  = 'doc.require_email';
        if ($requireEmailOnlyGuest && !Factory::getUser()->guest) {
            $requireEmailOverride = '0';
        }
        $query->select("{$requireEmailOverride} as require_user_email");

        return $query;
    }

    public function incrementDownloadCount($itemId)
    {
        parent::incrementDownloadCount($itemId);

        $user = Factory::getUser();
        $db   = Factory::getDbo();

        $query = $db->getQuery(true)
            ->insert('#__osdownloads_download_log')
            ->set('document_id = ' . $db->quote((int)$itemId))
            ->set('download_on = NOW()')
            ->set('user_id = ' . $db->quote((int)$user->id));
        $db->setQuery($query);
        $db->execute();
    }
}
