<?php
/**
 * @package   OSDownloads-Pro
 * @contact   www.joomlashack.com, help@joomlashack.com
 * @copyright 2005-2020 Joomlashack.com. All rights reserved
 * @license   http://www.gnu.org/licenses/gpl.html GNU/GPL
 *
 * This file is part of OSDownloads-Pro.
 *
 * OSDownloads-Pro is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 2 of the License, or
 * (at your option) any later version.
 *
 * OSDownloads-Pro is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with OSDownloads-Pro.  If not, see <http://www.gnu.org/licenses/>.
 */

namespace Alledia\OSDownloads\Pro\MailingList;

use Alledia\OSDownloads\MailingLists\AbstractClient;
use Alledia\OSDownloads\Pro\MailingList\AcyMailing\AbstractVersion;
use Exception as Exception;

defined('_JEXEC') or die();

class AcyMailing extends AbstractClient
{
    /**
     * @var bool
     */
    protected static $enabled = null;

    /**
     * @var object[]
     */
    protected static $lists = null;

    /**
     * @var AbstractVersion
     */
    protected static $methods = null;

    /**
     * @return array
     * @throws Exception
     */
    public static function getLists()
    {
        if (static::checkDependencies() && static::$lists === null) {
            static::$lists = static::$methods->getLists();
        }

        return static::$lists ?: array();
    }

    /**
     * @param bool $result
     *
     * @return void
     */
    public function onBeforeStore()
    {
        if (!static::isEnabled()) {
            return;
        }

        $joomlaUser             = $this->getUserByEmail($this->table->email);
        $this->table->confirmed = $joomlaUser ? 1 : 0;

        $user = static::$methods->getUser(
            $this->table->email,
            $this->table->confirmed,
            $joomlaUser ? $joomlaUser->id : null
        );

        $lists = (array)$this->getDocumentParam($this->table->document_id, 'mailinglist.acymailing.list_id', []);
        $lists = array_filter($lists);

        if ($user && $lists) {
            $this->table->synced = (int)static::$methods->subscribe($user, $lists);
        }
    }

    /**
     * If AcyMailing is not installed, will  completely disable this plugin
     *
     * @return bool
     */
    public static function checkDependencies()
    {
        if (static::$methods === null) {
            static::$methods = AbstractVersion::getInstance();
        }

        return static::$methods !== null;
    }

    public static function isEnabled()
    {
        return static::checkDependencies() && static::getParams()->get('mailinglist.acymailing.enable');
    }
}
