<?php
/**
 * @package   OSDownloads-Pro
 * @contact   www.joomlashack.com, help@joomlashack.com
 * @copyright 2019-2020 Joomlashack.com. All rights reserved
 * @license   http://www.gnu.org/licenses/gpl.html GNU/GPL
 *
 * This file is part of OSDownloads-Pro.
 *
 * OSDownloads-Pro is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 2 of the License, or
 * (at your option) any later version.
 *
 * OSDownloads-Pro is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with OSDownloads-Pro.  If not, see <http://www.gnu.org/licenses/>.
 */

namespace Alledia\OSDownloads\Pro\MailingList\AcyMailing;

defined('_JEXEC') or die();

abstract class AbstractVersion
{
    /**
     * @var static
     */
    protected static $instance = null;

    /**
     * @var \cpanelClass|\acymconfigurationClass
     */
    protected static $config = null;

    /**
     * @return AbstractVersion
     */
    public static function getInstance()
    {
        if (static::$config === null) {
            $version5 = JPATH_ADMINISTRATOR . '/components/com_acymailing/helpers/helper.php';
            $version6 = JPATH_ADMINISTRATOR . '/components/com_acym/helpers/helper.php';
            if (is_file($version5)) {
                require_once $version5;

                /** @var \cpanelClass $config */
                static::$config = acymailing_config();

                $versionClass = __NAMESPACE__ . '\\V5';

            } elseif (is_file($version6)) {
                require_once $version6;

                /** @var \acymconfigurationClass $config */
                static::$config = acym_config();

                $versionClass = __NAMESPACE__ . '\\V6';
            }
        }

        if (static::$instance === null) {
            if (!empty($versionClass) and class_exists($versionClass)) {
                static::$instance = new $versionClass();
            }
        }

        return static::$instance;
    }

    /**
     * @return object[]
     */
    abstract public function getLists();

    /**
     * Get/Create user in AcyMailing user list
     *
     * @param string $email
     * @param int    $confirmed
     * @param int    $userId
     *
     * @return object
     */
    abstract public function getUser($email, $confirmed, $userId);

    /**
     * @param object $user
     * @param int[]  $lists
     *
     * @return bool
     */
    abstract public function subscribe($user, array $lists);
}
