<?php
/**
 * @package   ShackForms
 * @contact   www.joomlashack.com, help@joomlashack.com
 * @copyright 2018-2020 Joomlashack.com. All rights reserved
 * @license   http://www.gnu.org/licenses/gpl.html GNU/GPL
 *
 * This file is part of ShackForms.
 *
 * ShackForms is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 2 of the License, or
 * (at your option) any later version.
 *
 * ShackForms is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with ShackForms.  If not, see <http://www.gnu.org/licenses/>.
 */

namespace Alledia\OSDownloads\Pro\MailingList\AcyMailing;

defined('_JEXEC') or die();

/**
 * Class V5
 *
 * @package Alledia\OSDownloads\Pro\MailingList\AcyMailing
 */
class V5 extends AbstractVersion
{
    /**
     * @return object[]
     */
    public function getLists()
    {
        /** @var \listClass $listClass */
        $listClass = acymailing_get('class.list');

        $lists = $listClass->getLists();

        array_walk(
            $lists,
            function (&$row) {
                $row->id = $row->listid;
            }
        );

        return $lists;
    }

    /**
     * @param string $email
     * @param int    $confirmed
     * @param int    $userId
     *
     * @return mixed|object
     */
    public function getUser($email, $confirmed, $userId)
    {
        /** @var \subscriberClass $acyUser */
        $acyUser = acymailing_get('class.subscriber');

        $user = $acyUser->get($email);
        if (!$user) {
            $user = (object)array(
                'email'     => $email,
                'confirmed' => $confirmed
            );

            $acyUserId = $acyUser->save($user);
            $user      = $acyUser->get($acyUserId);
        }

        if ($user && $userId && $user->userid != $userId) {
            $user->userid = $userId;
            $acyUser->save($user);
        }

        return $user;
    }

    /**
     * @param object $user
     * @param int[]  $lists
     *
     * @return bool
     */
    public function subscribe($user, array $lists)
    {
        $success = true;

        if (!empty($user->subid)) {
            $subscriptions = array_flip(array_filter($lists));
            foreach ($subscriptions as &$subscription) {
                $subscription = array(
                    'status' => 1
                );
            }

            if ($subscriptions) {
                /** @var \subscriberClass $acyUser */
                $acyUser = acymailing_get('class.subscriber');

                $success = $acyUser->saveSubscription($user->subid, $subscriptions);
            }
        }

        return $success;
    }
}
