<?php
/**
 * @package   ShackForms
 * @contact   www.joomlashack.com, help@joomlashack.com
 * @copyright 2018-2020 Joomlashack.com. All rights reserved
 * @license   http://www.gnu.org/licenses/gpl.html GNU/GPL
 *
 * This file is part of ShackForms.
 *
 * ShackForms is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 2 of the License, or
 * (at your option) any later version.
 *
 * ShackForms is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with ShackForms.  If not, see <http://www.gnu.org/licenses/>.
 */

namespace Alledia\OSDownloads\Pro\MailingList\AcyMailing;

defined('_JEXEC') or die();

class V6 extends AbstractVersion
{
    /**
     * @return object[]
     */
    public function getLists()
    {
        /** @var \acymlistClass $listClass */
        $listClass = acym_get('class.list');

        $lists = $listClass->getAll();

        return $lists;
    }

    /**
     * @param object $user
     * @param int[]  $lists
     *
     * @return bool
     */
    public function subscribe($user, array $lists)
    {
        $success = false;
        if (!empty($user->id)) {
            $lists = array_filter($lists);
            if ($lists) {
                /** @var \acymuserClass $userClass */
                $userClass = acym_get('class.user');

                $userClass->subscribe($user->id, $lists);

                $subscriptions = array_map(
                    function ($list) {
                        return $list->id;
                    },
                    $userClass->getUsersSubscriptionsByIds([$user->id])
                );

                $success = count(array_intersect($lists, $subscriptions)) > 0;
            }
        }

        return $success;
    }

    /**
     * Get/Create user in AcyMailing user list
     *
     * @param string $email
     * @param int    $confirmed
     * @param int    $userId
     *
     * @return object
     */
    public function getUser($email, $confirmed, $userId)
    {
        /** @var \acymuserClass $acyUser */
        $acyUser = acym_get('class.user');

        $user = $acyUser->getOneByEmail($email);
        if (!$user) {
            $user = (object)array(
                'email'     => $email,
                'confirmed' => $confirmed
            );

            $acyUserId = $acyUser->save($user);
            $user      = $acyUser->getOneById($acyUserId);

        } else {
            $acyUser->save($user);
        }

        return $user;
    }
}
