<?php
/**
 * @package   OSDownloads-Pro
 * @contact   www.joomlashack.com, help@joomlashack.com
 * @copyright 2005-2020 Joomlashack.com. All rights reserved
 * @license   http://www.gnu.org/licenses/gpl.html GNU/GPL
 *
 * This file is part of OSDownloads-Pro.
 *
 * OSDownloads-Pro is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 2 of the License, or
 * (at your option) any later version.
 *
 * OSDownloads-Pro is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with OSDownloads-Pro.  If not, see <http://www.gnu.org/licenses/>.
 */

namespace Alledia\OSDownloads\Pro\MailingList;

use Alledia\OSDownloads\MailingLists\AbstractClient;
use Ctct\Components\Contacts\Contact;
use Joomla\CMS\Factory;
use Joomla\CMS\Language\Text;

defined('_JEXEC') or die();

class ConstantContact extends AbstractClient
{
    const STATUS_UNCONFIRMED    = 'UNCONFIRMED';
    const STATUS_ACTIVE         = 'ACTIVE';
    const STATUS_OPTOUT         = 'OPTOUT';
    const STATUS_REMOVED        = 'REMOVED';
    const STATUS_NON_SUBSCRIBER = 'NON_SUBSCRIBER';

    /**
     * @var \Ctct\ConstantContact
     */
    protected static $constantContact = null;

    /**
     * @var string
     */
    protected static $accessToken = null;

    /**
     * @param bool
     *
     * @return void
     * @throws \Exception
     */
    public function onBeforeStore()
    {
        if (!static::isEnabled()) {
            return;
        }

        $cc         = static::getConstantContact();
        $email      = empty($this->table->email) ? null : $this->table->email;
        $documentId = $this->table->document_id;

        $listId = $this->getDocumentParam($documentId, 'mailinglist.cc.list_id');
        if ($cc && $email && $listId) {
            try {
                $status        = $this->getDocumentParam($documentId, 'mailinglist.cc.status', static::STATUS_ACTIVE);
                $contactParams = [
                    'action_by' => 'ACTION_BY_VISITOR'
                ];

                $resultSet = $cc->contactService->getContacts(static::$accessToken, ['email' => $email]);
                if (empty($resultSet->results)) {
                    $contact = Contact::create(['status' => $status,]);

                    $contact->addEmail($email);
                    $contact->addList($listId);

                    $cc->contactService->addContact(static::$accessToken, $contact, $contactParams);

                    $this->table->synced = $contact->status === static::STATUS_ACTIVE ? 1 : 0;

                } else {
                    // Should be only one, but let's use a loop anyway.
                    $synced = $this->table->synced;

                    /** @var Contact $contact */
                    foreach ($resultSet->results as $contact) {
                        $contact->status = $status;

                        $contact->addList($listId);
                        $cc->contactService->updateContact(static::$accessToken, $contact, $contactParams);

                        $synced = $synced || ($contact->status === static::STATUS_ACTIVE ? 1 : 0);
                    }

                    $this->table->synced = $synced;
                }

            } catch (\Exception $error) {
                // See below
            } catch (\Throwable $error) {
                // See below
            }

            if (!empty($error)) {
                Factory::getApplication()->enqueueMessage(
                    Text::sprintf('COM_OSDOWNLOADS_ERROR_MAILING_LIST', $error->getMessage()),
                    'error'
                );
            }
        }
    }

    /**
     * @return \Ctct\ConstantContact
     */
    public static function getConstantContact()
    {
        if (static::$constantContact === null) {
            static::$constantContact = false;

            $params      = static::getParams();
            $apiKey      = $params->get('mailinglist.cc.apikey');
            $accessToken = $params->get('mailinglist.cc.access_token');

            if ($apiKey && $accessToken) {
                $autoloadPath = JPATH_ADMINISTRATOR . '/components/com_osdownloads/library/Ctct/autoload.php';
                if (is_file($autoloadPath)) {
                    require_once $autoloadPath;
                }

                if (class_exists('\\Ctct\\ConstantContact')) {
                    static::$constantContact = new \Ctct\ConstantContact($apiKey);
                    static::$accessToken     = $accessToken;
                }
            }
        }

        return static::$constantContact ?: null;
    }

    /**
     * @inheritDoc
     */
    public static function isEnabled()
    {
        return static::getParams()->get('mailinglist.cc.enable');
    }
}
