<?php
/**
 * @package   OSDownloads-Pro
 * @contact   www.joomlashack.com, help@joomlashack.com
 * @copyright 2005-2020 Joomlashack.com. All rights reserved
 * @license   http://www.gnu.org/licenses/gpl.html GNU/GPL
 *
 * This file is part of OSDownloads-Pro.
 *
 * OSDownloads-Pro is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 2 of the License, or
 * (at your option) any later version.
 *
 * OSDownloads-Pro is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with OSDownloads-Pro.  If not, see <http://www.gnu.org/licenses/>.
 */

namespace Alledia\OSDownloads\Pro\MailingList;

use Alledia\OSDownloads\Free;
use Exception;

defined('_JEXEC') or die();

class MailChimp extends Free\MailingList\MailChimp
{
    /**
     * Check with Mailchimp and indicate synced status
     * Add to selected Mailchimp Audience/groups
     */
    public function onBeforeStore()
    {
        if (!static::isEnabled()) {
            return;
        }

        $email = empty($this->table->email) ? null : $this->table->email;
        $mc    = static::getMailChimp();

        $documentId = $this->table->document_id;
        $listId     = $this->getDocumentParam($documentId, 'mailinglist.mailchimp.list_id');
        $groups     = $this->getDocumentParam($documentId, 'mailinglist.mailchimp.groups');

        if ($email && $listId && $mc) {
            try {
                // Check if the email already exists
                $result = $mc->get("lists/{$listId}/members/" . md5(strtolower($email)));
                $result = $result->toArray();

            } catch (Exception $error) {
                $result = array('status' => 'unsubscribed');
            }

            if ($result['status'] !== 'subscribed') {
                $interests = array();
                if (!empty($groups)) {
                    $interests = array();
                    foreach ($groups as $group) {
                        $interests[$group] = true;
                    }
                }

                // The email is not subscribed. Let's subscribe it.
                try {
                    $doubleOptIn = (bool)static::getParams()->get("mailinglist.mailchimp.double_optin", false);

                    $options = array(
                        'email_address' => $email,
                        'status'        => $doubleOptIn ? 'pending' : 'subscribed'
                    );
                    if ($interests) {
                        $options['interests'] = $interests;
                    }

                    $result = $mc->post("lists/{$listId}/members/", $options);
                    $result = $result->toArray();

                } catch (Exception $e) {
                    if ($response = json_decode($e->getMessage())) {
                        $response = $response->detail;
                    } else {
                        $response = $e->getMessage();
                    }

                    $this->logError($response);
                }
            }

            $this->table->synced = ($result['status'] === 'subscribed') ? 1 : 0;
        }
    }

    public function onAfterStore($result)
    {
        // Disable the free handler since we do everything before store in Pro
    }
}
