<?php
/**
 * @package   OSDownloads-Pro
 * @contact   www.joomlashack.com, help@joomlashack.com
 * @copyright 2005-2020 Joomlashack.com. All rights reserved
 * @license   http://www.gnu.org/licenses/gpl.html GNU/GPL
 *
 * This file is part of OSDownloads-Pro.
 *
 * OSDownloads-Pro is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 2 of the License, or
 * (at your option) any later version.
 *
 * OSDownloads-Pro is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with OSDownloads-Pro.  If not, see <http://www.gnu.org/licenses/>.
 */

defined('_JEXEC') or die();

require_once JPATH_SITE . '/components/com_osdownloads/models/item.php';

use Alledia\OSDownloads\Free\Joomla\View;
use Alledia\OSDownloads\Free\Factory;
use Joomla\CMS\Application\SiteApplication;
use Joomla\Registry\Registry;

class OSDownloadsViewCategories extends View\Site\Base
{
    /**
     * @var Registry
     */
    protected $params = null;

    /**
     * @var object[]
     */
    protected $categories = null;

    /**
     * @var JPagination
     */
    protected $pagination = null;

    /**
     * @var bool
     */
    protected $isPro = false;

    /**
     * @var bool
     */
    protected $showDescriptions = false;

    /**
     * @param string $tpl
     *
     * @return void
     * @throws Exception
     */
    public function display($tpl = null)
    {
        /** @var SiteApplication $app */
        $app       = JFactory::getApplication();
        $db        = JFactory::getDBO();
        $container = Factory::getContainer();

        $params = $app->getParams();
        $id     = $app->input->getInt('id', 1);

        $menu = $app->getMenu()->getActive();
        if ($menu) {
            $params->def('page_heading', $params->get('page_title', $menu->title));
        }

        // Load the library
        $extension = Alledia\Framework\Factory::getExtension('OSDownloads', 'component');
        $extension->loadLibrary();

        /*----------  Pagination  ----------*/
        $limit      = $app->getUserStateFromRequest('global.list.limit', 'limit', $app->getCfg('list_limit'), 'int');
        $limitstart = $app->getUserStateFromRequest('osdownloads.request.limitstart', 'limitstart', 0, 'int');

        $filterOrder = $params->get('ordering', 'cat.lft');

        // Fix wrong filter
        if ('ordering' === $filterOrder) {
            $filterOrder = 'cat.lft';
        }

        $app->setUserState("com_osdownloads.category.filter_order", $filterOrder);
        $app->setUserState("com_osdownloads.category.filter_order_Dir", $params->get('ordering_dir', 'asc'));

        $model = JModelLegacy::getInstance('OSDownloadsModelCategories');
        $query = $model->getChildCategoriesQuery($id);

        $db->setQuery($query);
        $db->execute();

        $total = $db->getNumRows();

        $pagination = new JPagination($total, $limitstart, $limit);

        /*----------  Child Categories  ----------*/
        $db->setQuery($query, $pagination->limitstart, $pagination->limit);
        $categories = $db->loadObjectList();

        $user   = JFactory::getUser();
        $groups = $user->getAuthorisedViewLevels();

        if (!isset($categories) || (count($categories) && !in_array($categories[0]->access, $groups))) {
            JError::raiseWarning(404, JText::_("COM_OSDOWNLOADS_THIS_CATEGORY_ISNT_AVAILABLE"));

            return;
        }

        // Set additional data to each category
        if (!empty($categories)) {
            $model            = JModelLegacy::getInstance('OSDownloadsModelCategories');
            $itemId           = $app->input->getInt('Itemid');
            $ignoreCategories = (array)$params->get('ignore_categories', array());

            foreach ($categories as &$category) {
                if (in_array($category->id, $ignoreCategories)) {
                    $category->hide = true;

                    continue;
                }

                // Do we have children
                $category->hasChildren = $this->checkCategoryHasChildren($category->id);
                // The total of files
                $category->totalFiles = $model->getTotalCategoryFiles($category->id);
                // Should we hide the category?
                $category->hide = (empty($category->totalFiles) && !$category->hasChildren);
                // What is the link?
                $category->link = $category->hasChildren ?
                    $container->helperRoute->getCategoriesRoute($category->id, $itemId) :
                    $container->helperRoute->getFileListRoute($category->id, $itemId);
            }
        }

        $container->helperView->buildCategoryBreadcrumbs($id);

        $this->params           = $params;
        $this->categories       = $categories;
        $this->pagination       = $pagination;
        $this->isPro            = $extension->isPro();
        $this->showDescriptions = (bool)$params->get('show_descriptions', 1);

        parent::display($tpl);
    }

    /**
     * Check if the category has child categories.
     *
     * @param  int $categoryId
     *
     * @return bool
     */
    protected function checkCategoryHasChildren($categoryId)
    {
        $model    = JModelLegacy::getInstance('OSDownloadsModelCategories');
        $hasChild = $model->getTotalCategoryChildren($categoryId) > 0;

        return $hasChild;
    }
}
